# -*- coding: utf-8 -*-


"""
Module ConfigurationSetting

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    SofaDefaultPathSetting

    StartNavigationButtonSetting

    FixPickedParticleButtonSetting

    AttachBodyButtonSetting

    AddFrameButtonSetting

    ViewerSetting

    StatsSetting

    BackgroundSetting

    AddRecordedCameraButtonSetting



Content:
========

.. automodule::

    SofaDefaultPathSetting

    StartNavigationButtonSetting

    FixPickedParticleButtonSetting

    AttachBodyButtonSetting

    AddFrameButtonSetting

    ViewerSetting

    StatsSetting

    BackgroundSetting

    AddRecordedCameraButtonSetting



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['SofaDefaultPathSetting', 'StartNavigationButtonSetting', 'FixPickedParticleButtonSetting', 'AttachBodyButtonSetting', 'AddFrameButtonSetting', 'ViewerSetting', 'StatsSetting', 'BackgroundSetting', 'AddRecordedCameraButtonSetting']
class ConfigurationSetting:
    from .SofaDefaultPathSetting import SofaDefaultPathSetting
    from .StartNavigationButtonSetting import StartNavigationButtonSetting
    from .FixPickedParticleButtonSetting import FixPickedParticleButtonSetting
    from .AttachBodyButtonSetting import AttachBodyButtonSetting
    from .AddFrameButtonSetting import AddFrameButtonSetting
    from .ViewerSetting import ViewerSetting
    from .StatsSetting import StatsSetting
    from .BackgroundSetting import BackgroundSetting
    from .AddRecordedCameraButtonSetting import AddRecordedCameraButtonSetting
