# -*- coding: utf-8 -*-


"""
Module MechanicalState

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    MechanicalObject



Content:
========

.. automodule::

    MechanicalObject



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['MechanicalObject']
class MechanicalState:
    from .MechanicalObject import MechanicalObject
