# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component BeamFEMForceField

.. autofunction:: BeamFEMForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def BeamFEMForceField(self, **kwargs):
    """
    Beam finite elements



    """
    params = dict()
    return "BeamFEMForceField", params
