# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component DistanceFromTargetMapping

.. autofunction:: DistanceFromTargetMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def DistanceFromTargetMapping(self, **kwargs):
    """
    Compute edge extensions



    """
    params = dict()
    return "DistanceFromTargetMapping", params
