# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component Mesh2PointMechanicalMapping

.. autofunction:: Mesh2PointMechanicalMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def Mesh2PointMechanicalMapping(self, **kwargs):
    """
    Mechanical mapping between a set of mesh primitives (point, edge, triangle...) and a set of points generated by Mesh2PointTopologicalMapping



    """
    params = dict()
    return "Mesh2PointMechanicalMapping", params
