# -*- coding: utf-8 -*-


"""
Module ContextObject

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    Gravity



Content:
========

.. automodule::

    Gravity



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['Gravity']
class ContextObject:
    from .Gravity import Gravity
