# -*- coding: utf-8 -*-


"""
Module Legacy

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    GearSpringForceField

    TriangleDeformationMapping

    VolumeMapping

    DeformableOnRigidFrameMapping

    VolumePreservationForceField

    SubsetMapping

    Tetra2TriangleTopologicalMapping

    TubularMapping

    PlasticStrainMapping

    LinearMapping

    AffineMass

    SimpleTesselatedTetraTopologicalMapping

    SpringForceField

    RepulsiveSpringForceField

    BarycentricMapping

    LCPForceFeedback

    Quad2TriangleTopologicalMapping

    Hexa2QuadTopologicalMapping

    InvariantMapping

    TetrahedronVolumeMapping

    StiffSpringForceField

    CorotationalStrainMapping

    StabilizedNeoHookeanForceField

    TriangleStrainAverageMapping

    FixedRotationConstraint

    NeoHookeanForceField

    SlidingConstraint

    Distances

    UniformConstraint

    IdentityMapping

    SubsetMultiMapping

    BeamLinearMapping

    DistanceFromTargetMapping

    Mesh2PointTopologicalMapping

    PrincipalStretchesMapping

    CenterPointTopologicalMapping

    SquareDistanceMapping

    DevAngleCollisionMonitor

    FixedTranslationConstraint

    SkinningMapping

    DistanceMultiMapping

    DistanceMapping

    AngularSpringForceField

    DevTensionMonitor

    CenterOfMassMapping

    BeamFEMForceField

    CorotationalMeshMapping

    MuscleMaterialForceField

    RegularGridSpringForceField

    Edge2QuadTopologicalMapping

    LineSetSkinningMapping

    PolynomialMaterialForceField

    VectorSpringForceField

    PythonMainScriptController

    SimpleTesselatedHexaTopologicalMapping

    PenalityContactForceField

    IdentityMultiMapping

    IdentityTopologicalMapping

    TendonMaterialForceField

    ContactListener

    OBBCollisionModel

    HookeOrthotropicForceField

    CenterOfMassMultiMapping

    OgdenForceField

    ProjectiveForceField

    SkeletalMotionConstraint

    RelativeStrainMapping

    CompareTopology

    Hexa2TetraTopologicalMapping

    Mesh2PointMechanicalMapping

    CenterOfMassMulti2Mapping

    StabilizedHookeForceField

    JointSpringForceField

    SimpleTesselatedTetraMechanicalMapping

    StopperConstraint

    QuadBendingSprings

    FrameSpringForceField

    HookeForceField

    GreenStrainMapping

    MeshSpringForceField

    HookeTransverseForceField

    RigidMapping

    MLSMapping

    LinearMultiMapping

    MooneyRivlinForceField

    LinearStrainMapping

    CauchyStrainMapping

    SubsetTopologicalMapping

    ArticulatedSystemMapping

    RigidRigidMapping

    TriangleBendingSprings

    UnilateralInteractionConstraint

    Triangle2EdgeTopologicalMapping

    RigidConstraint

    HEMLStVKForceField

    SquareMapping

    HexahedronCompositeFEMMapping



Content:
========

.. automodule::

    GearSpringForceField

    TriangleDeformationMapping

    VolumeMapping

    DeformableOnRigidFrameMapping

    VolumePreservationForceField

    SubsetMapping

    Tetra2TriangleTopologicalMapping

    TubularMapping

    PlasticStrainMapping

    LinearMapping

    AffineMass

    SimpleTesselatedTetraTopologicalMapping

    SpringForceField

    RepulsiveSpringForceField

    BarycentricMapping

    LCPForceFeedback

    Quad2TriangleTopologicalMapping

    Hexa2QuadTopologicalMapping

    InvariantMapping

    TetrahedronVolumeMapping

    StiffSpringForceField

    CorotationalStrainMapping

    StabilizedNeoHookeanForceField

    TriangleStrainAverageMapping

    FixedRotationConstraint

    NeoHookeanForceField

    SlidingConstraint

    Distances

    UniformConstraint

    IdentityMapping

    SubsetMultiMapping

    BeamLinearMapping

    DistanceFromTargetMapping

    Mesh2PointTopologicalMapping

    PrincipalStretchesMapping

    CenterPointTopologicalMapping

    SquareDistanceMapping

    DevAngleCollisionMonitor

    FixedTranslationConstraint

    SkinningMapping

    DistanceMultiMapping

    DistanceMapping

    AngularSpringForceField

    DevTensionMonitor

    CenterOfMassMapping

    BeamFEMForceField

    CorotationalMeshMapping

    MuscleMaterialForceField

    RegularGridSpringForceField

    Edge2QuadTopologicalMapping

    LineSetSkinningMapping

    PolynomialMaterialForceField

    VectorSpringForceField

    PythonMainScriptController

    SimpleTesselatedHexaTopologicalMapping

    PenalityContactForceField

    IdentityMultiMapping

    IdentityTopologicalMapping

    TendonMaterialForceField

    ContactListener

    OBBCollisionModel

    HookeOrthotropicForceField

    CenterOfMassMultiMapping

    OgdenForceField

    ProjectiveForceField

    SkeletalMotionConstraint

    RelativeStrainMapping

    CompareTopology

    Hexa2TetraTopologicalMapping

    Mesh2PointMechanicalMapping

    CenterOfMassMulti2Mapping

    StabilizedHookeForceField

    JointSpringForceField

    SimpleTesselatedTetraMechanicalMapping

    StopperConstraint

    QuadBendingSprings

    FrameSpringForceField

    HookeForceField

    GreenStrainMapping

    MeshSpringForceField

    HookeTransverseForceField

    RigidMapping

    MLSMapping

    LinearMultiMapping

    MooneyRivlinForceField

    LinearStrainMapping

    CauchyStrainMapping

    SubsetTopologicalMapping

    ArticulatedSystemMapping

    RigidRigidMapping

    TriangleBendingSprings

    UnilateralInteractionConstraint

    Triangle2EdgeTopologicalMapping

    RigidConstraint

    HEMLStVKForceField

    SquareMapping

    HexahedronCompositeFEMMapping



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['GearSpringForceField', 'TriangleDeformationMapping', 'VolumeMapping', 'DeformableOnRigidFrameMapping', 'VolumePreservationForceField', 'SubsetMapping', 'Tetra2TriangleTopologicalMapping', 'TubularMapping', 'PlasticStrainMapping', 'LinearMapping', 'AffineMass', 'SimpleTesselatedTetraTopologicalMapping', 'SpringForceField', 'RepulsiveSpringForceField', 'BarycentricMapping', 'LCPForceFeedback', 'Quad2TriangleTopologicalMapping', 'Hexa2QuadTopologicalMapping', 'InvariantMapping', 'TetrahedronVolumeMapping', 'StiffSpringForceField', 'CorotationalStrainMapping', 'StabilizedNeoHookeanForceField', 'TriangleStrainAverageMapping', 'FixedRotationConstraint', 'NeoHookeanForceField', 'SlidingConstraint', 'Distances', 'UniformConstraint', 'IdentityMapping', 'SubsetMultiMapping', 'BeamLinearMapping', 'DistanceFromTargetMapping', 'Mesh2PointTopologicalMapping', 'PrincipalStretchesMapping', 'CenterPointTopologicalMapping', 'SquareDistanceMapping', 'DevAngleCollisionMonitor', 'FixedTranslationConstraint', 'SkinningMapping', 'DistanceMultiMapping', 'DistanceMapping', 'AngularSpringForceField', 'DevTensionMonitor', 'CenterOfMassMapping', 'BeamFEMForceField', 'CorotationalMeshMapping', 'MuscleMaterialForceField', 'RegularGridSpringForceField', 'Edge2QuadTopologicalMapping', 'LineSetSkinningMapping', 'PolynomialMaterialForceField', 'VectorSpringForceField', 'PythonMainScriptController', 'SimpleTesselatedHexaTopologicalMapping', 'PenalityContactForceField', 'IdentityMultiMapping', 'IdentityTopologicalMapping', 'TendonMaterialForceField', 'ContactListener', 'OBBCollisionModel', 'HookeOrthotropicForceField', 'CenterOfMassMultiMapping', 'OgdenForceField', 'ProjectiveForceField', 'SkeletalMotionConstraint', 'RelativeStrainMapping', 'CompareTopology', 'Hexa2TetraTopologicalMapping', 'Mesh2PointMechanicalMapping', 'CenterOfMassMulti2Mapping', 'StabilizedHookeForceField', 'JointSpringForceField', 'SimpleTesselatedTetraMechanicalMapping', 'StopperConstraint', 'QuadBendingSprings', 'FrameSpringForceField', 'HookeForceField', 'GreenStrainMapping', 'MeshSpringForceField', 'HookeTransverseForceField', 'RigidMapping', 'MLSMapping', 'LinearMultiMapping', 'MooneyRivlinForceField', 'LinearStrainMapping', 'CauchyStrainMapping', 'SubsetTopologicalMapping', 'ArticulatedSystemMapping', 'RigidRigidMapping', 'TriangleBendingSprings', 'UnilateralInteractionConstraint', 'Triangle2EdgeTopologicalMapping', 'RigidConstraint', 'HEMLStVKForceField', 'SquareMapping', 'HexahedronCompositeFEMMapping']
class Legacy:
    from .GearSpringForceField import GearSpringForceField
    from .TriangleDeformationMapping import TriangleDeformationMapping
    from .VolumeMapping import VolumeMapping
    from .DeformableOnRigidFrameMapping import DeformableOnRigidFrameMapping
    from .VolumePreservationForceField import VolumePreservationForceField
    from .SubsetMapping import SubsetMapping
    from .Tetra2TriangleTopologicalMapping import Tetra2TriangleTopologicalMapping
    from .TubularMapping import TubularMapping
    from .PlasticStrainMapping import PlasticStrainMapping
    from .LinearMapping import LinearMapping
    from .AffineMass import AffineMass
    from .SimpleTesselatedTetraTopologicalMapping import SimpleTesselatedTetraTopologicalMapping
    from .SpringForceField import SpringForceField
    from .RepulsiveSpringForceField import RepulsiveSpringForceField
    from .BarycentricMapping import BarycentricMapping
    from .LCPForceFeedback import LCPForceFeedback
    from .Quad2TriangleTopologicalMapping import Quad2TriangleTopologicalMapping
    from .Hexa2QuadTopologicalMapping import Hexa2QuadTopologicalMapping
    from .InvariantMapping import InvariantMapping
    from .TetrahedronVolumeMapping import TetrahedronVolumeMapping
    from .StiffSpringForceField import StiffSpringForceField
    from .CorotationalStrainMapping import CorotationalStrainMapping
    from .StabilizedNeoHookeanForceField import StabilizedNeoHookeanForceField
    from .TriangleStrainAverageMapping import TriangleStrainAverageMapping
    from .FixedRotationConstraint import FixedRotationConstraint
    from .NeoHookeanForceField import NeoHookeanForceField
    from .SlidingConstraint import SlidingConstraint
    from .Distances import Distances
    from .UniformConstraint import UniformConstraint
    from .IdentityMapping import IdentityMapping
    from .SubsetMultiMapping import SubsetMultiMapping
    from .BeamLinearMapping import BeamLinearMapping
    from .DistanceFromTargetMapping import DistanceFromTargetMapping
    from .Mesh2PointTopologicalMapping import Mesh2PointTopologicalMapping
    from .PrincipalStretchesMapping import PrincipalStretchesMapping
    from .CenterPointTopologicalMapping import CenterPointTopologicalMapping
    from .SquareDistanceMapping import SquareDistanceMapping
    from .DevAngleCollisionMonitor import DevAngleCollisionMonitor
    from .FixedTranslationConstraint import FixedTranslationConstraint
    from .SkinningMapping import SkinningMapping
    from .DistanceMultiMapping import DistanceMultiMapping
    from .DistanceMapping import DistanceMapping
    from .AngularSpringForceField import AngularSpringForceField
    from .DevTensionMonitor import DevTensionMonitor
    from .CenterOfMassMapping import CenterOfMassMapping
    from .BeamFEMForceField import BeamFEMForceField
    from .CorotationalMeshMapping import CorotationalMeshMapping
    from .MuscleMaterialForceField import MuscleMaterialForceField
    from .RegularGridSpringForceField import RegularGridSpringForceField
    from .Edge2QuadTopologicalMapping import Edge2QuadTopologicalMapping
    from .LineSetSkinningMapping import LineSetSkinningMapping
    from .PolynomialMaterialForceField import PolynomialMaterialForceField
    from .VectorSpringForceField import VectorSpringForceField
    from .PythonMainScriptController import PythonMainScriptController
    from .SimpleTesselatedHexaTopologicalMapping import SimpleTesselatedHexaTopologicalMapping
    from .PenalityContactForceField import PenalityContactForceField
    from .IdentityMultiMapping import IdentityMultiMapping
    from .IdentityTopologicalMapping import IdentityTopologicalMapping
    from .TendonMaterialForceField import TendonMaterialForceField
    from .ContactListener import ContactListener
    from .OBBCollisionModel import OBBCollisionModel
    from .HookeOrthotropicForceField import HookeOrthotropicForceField
    from .CenterOfMassMultiMapping import CenterOfMassMultiMapping
    from .OgdenForceField import OgdenForceField
    from .ProjectiveForceField import ProjectiveForceField
    from .SkeletalMotionConstraint import SkeletalMotionConstraint
    from .RelativeStrainMapping import RelativeStrainMapping
    from .CompareTopology import CompareTopology
    from .Hexa2TetraTopologicalMapping import Hexa2TetraTopologicalMapping
    from .Mesh2PointMechanicalMapping import Mesh2PointMechanicalMapping
    from .CenterOfMassMulti2Mapping import CenterOfMassMulti2Mapping
    from .StabilizedHookeForceField import StabilizedHookeForceField
    from .JointSpringForceField import JointSpringForceField
    from .SimpleTesselatedTetraMechanicalMapping import SimpleTesselatedTetraMechanicalMapping
    from .StopperConstraint import StopperConstraint
    from .QuadBendingSprings import QuadBendingSprings
    from .FrameSpringForceField import FrameSpringForceField
    from .HookeForceField import HookeForceField
    from .GreenStrainMapping import GreenStrainMapping
    from .MeshSpringForceField import MeshSpringForceField
    from .HookeTransverseForceField import HookeTransverseForceField
    from .RigidMapping import RigidMapping
    from .MLSMapping import MLSMapping
    from .LinearMultiMapping import LinearMultiMapping
    from .MooneyRivlinForceField import MooneyRivlinForceField
    from .LinearStrainMapping import LinearStrainMapping
    from .CauchyStrainMapping import CauchyStrainMapping
    from .SubsetTopologicalMapping import SubsetTopologicalMapping
    from .ArticulatedSystemMapping import ArticulatedSystemMapping
    from .RigidRigidMapping import RigidRigidMapping
    from .TriangleBendingSprings import TriangleBendingSprings
    from .UnilateralInteractionConstraint import UnilateralInteractionConstraint
    from .Triangle2EdgeTopologicalMapping import Triangle2EdgeTopologicalMapping
    from .RigidConstraint import RigidConstraint
    from .HEMLStVKForceField import HEMLStVKForceField
    from .SquareMapping import SquareMapping
    from .HexahedronCompositeFEMMapping import HexahedronCompositeFEMMapping
