# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MLSMapping

.. autofunction:: MLSMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MLSMapping(self, **kwargs):
    """
    Map child positions using generalized moving least squares.
Map child positions using moving least squares.
Map child positions using generalized moving least squares.
Map child positions using generalized moving least squares.



    """
    params = dict()
    return "MLSMapping", params
