# -*- coding: utf-8 -*-


"""
Module Mapping

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    VoidMapping



Content:
========

.. automodule:: VoidMapping
    :members:




Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['VoidMapping']
class Mapping:
    from .VoidMapping import VoidMapping
