# -*- coding: utf-8 -*-


"""
Module TopologyObject

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    TetrahedronSetTopologyContainer

    TriangleSetTopologyAlgorithms

    EdgeSetGeometryAlgorithms

    EdgeSetTopologyContainer

    HexahedronSetTopologyAlgorithms

    EdgeSetTopologyModifier

    MultilevelHexahedronSetTopologyContainer

    TriangleSetGeometryAlgorithms

    PointSetTopologyModifier

    TetrahedronSetTopologyAlgorithms

    PointSetTopologyContainer

    QuadSetTopologyContainer

    TetrahedronSetTopologyModifier

    QuadSetGeometryAlgorithms

    DynamicSparseGridTopologyModifier

    HexahedronSetGeometryAlgorithms

    PointSetGeometryAlgorithms

    QuadSetTopologyAlgorithms

    PointSetTopologyAlgorithms

    QuadSetTopologyModifier

    TriangleSetTopologyContainer

    HexahedronSetTopologyContainer

    EdgeSetTopologyAlgorithms

    DynamicSparseGridGeometryAlgorithms

    TriangleSetTopologyModifier

    HexahedronSetTopologyModifier

    DynamicSparseGridTopologyAlgorithms

    TetrahedronSetGeometryAlgorithms

    DynamicSparseGridTopologyContainer



Content:
========

.. automodule::

    TetrahedronSetTopologyContainer

    TriangleSetTopologyAlgorithms

    EdgeSetGeometryAlgorithms

    EdgeSetTopologyContainer

    HexahedronSetTopologyAlgorithms

    EdgeSetTopologyModifier

    MultilevelHexahedronSetTopologyContainer

    TriangleSetGeometryAlgorithms

    PointSetTopologyModifier

    TetrahedronSetTopologyAlgorithms

    PointSetTopologyContainer

    QuadSetTopologyContainer

    TetrahedronSetTopologyModifier

    QuadSetGeometryAlgorithms

    DynamicSparseGridTopologyModifier

    HexahedronSetGeometryAlgorithms

    PointSetGeometryAlgorithms

    QuadSetTopologyAlgorithms

    PointSetTopologyAlgorithms

    QuadSetTopologyModifier

    TriangleSetTopologyContainer

    HexahedronSetTopologyContainer

    EdgeSetTopologyAlgorithms

    DynamicSparseGridGeometryAlgorithms

    TriangleSetTopologyModifier

    HexahedronSetTopologyModifier

    DynamicSparseGridTopologyAlgorithms

    TetrahedronSetGeometryAlgorithms

    DynamicSparseGridTopologyContainer



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['TetrahedronSetTopologyContainer', 'TriangleSetTopologyAlgorithms', 'EdgeSetGeometryAlgorithms', 'EdgeSetTopologyContainer', 'HexahedronSetTopologyAlgorithms', 'EdgeSetTopologyModifier', 'MultilevelHexahedronSetTopologyContainer', 'TriangleSetGeometryAlgorithms', 'PointSetTopologyModifier', 'TetrahedronSetTopologyAlgorithms', 'PointSetTopologyContainer', 'QuadSetTopologyContainer', 'TetrahedronSetTopologyModifier', 'QuadSetGeometryAlgorithms', 'DynamicSparseGridTopologyModifier', 'HexahedronSetGeometryAlgorithms', 'PointSetGeometryAlgorithms', 'QuadSetTopologyAlgorithms', 'PointSetTopologyAlgorithms', 'QuadSetTopologyModifier', 'TriangleSetTopologyContainer', 'HexahedronSetTopologyContainer', 'EdgeSetTopologyAlgorithms', 'DynamicSparseGridGeometryAlgorithms', 'TriangleSetTopologyModifier', 'HexahedronSetTopologyModifier', 'DynamicSparseGridTopologyAlgorithms', 'TetrahedronSetGeometryAlgorithms', 'DynamicSparseGridTopologyContainer']
class TopologyObject:
    from .TetrahedronSetTopologyContainer import TetrahedronSetTopologyContainer
    from .TriangleSetTopologyAlgorithms import TriangleSetTopologyAlgorithms
    from .EdgeSetGeometryAlgorithms import EdgeSetGeometryAlgorithms
    from .EdgeSetTopologyContainer import EdgeSetTopologyContainer
    from .HexahedronSetTopologyAlgorithms import HexahedronSetTopologyAlgorithms
    from .EdgeSetTopologyModifier import EdgeSetTopologyModifier
    from .MultilevelHexahedronSetTopologyContainer import MultilevelHexahedronSetTopologyContainer
    from .TriangleSetGeometryAlgorithms import TriangleSetGeometryAlgorithms
    from .PointSetTopologyModifier import PointSetTopologyModifier
    from .TetrahedronSetTopologyAlgorithms import TetrahedronSetTopologyAlgorithms
    from .PointSetTopologyContainer import PointSetTopologyContainer
    from .QuadSetTopologyContainer import QuadSetTopologyContainer
    from .TetrahedronSetTopologyModifier import TetrahedronSetTopologyModifier
    from .QuadSetGeometryAlgorithms import QuadSetGeometryAlgorithms
    from .DynamicSparseGridTopologyModifier import DynamicSparseGridTopologyModifier
    from .HexahedronSetGeometryAlgorithms import HexahedronSetGeometryAlgorithms
    from .PointSetGeometryAlgorithms import PointSetGeometryAlgorithms
    from .QuadSetTopologyAlgorithms import QuadSetTopologyAlgorithms
    from .PointSetTopologyAlgorithms import PointSetTopologyAlgorithms
    from .QuadSetTopologyModifier import QuadSetTopologyModifier
    from .TriangleSetTopologyContainer import TriangleSetTopologyContainer
    from .HexahedronSetTopologyContainer import HexahedronSetTopologyContainer
    from .EdgeSetTopologyAlgorithms import EdgeSetTopologyAlgorithms
    from .DynamicSparseGridGeometryAlgorithms import DynamicSparseGridGeometryAlgorithms
    from .TriangleSetTopologyModifier import TriangleSetTopologyModifier
    from .HexahedronSetTopologyModifier import HexahedronSetTopologyModifier
    from .DynamicSparseGridTopologyAlgorithms import DynamicSparseGridTopologyAlgorithms
    from .TetrahedronSetGeometryAlgorithms import TetrahedronSetGeometryAlgorithms
    from .DynamicSparseGridTopologyContainer import DynamicSparseGridTopologyContainer
